@@ -139,10 +139,8 @@ class SpotifySessionManager(BaseThread, PyspotifySessionManager):
     def refresh_stored_playlists(self):
         """Refresh the stored playlists in the backend with fresh meta data
         from Spotify"""
-        playlists = []
-        for spotify_playlist in self.session.playlist_container():
-            playlists.append(
-                SpotifyTranslator.to_mopidy_playlist(spotify_playlist))
+        playlists = map(SpotifyTranslator.to_mopidy_playlist,
+            self.session.playlist_container())
         playlists = filter(None, playlists)
         self.backend.stored_playlists.playlists = playlists
         logger.debug(u'Refreshed %d stored playlist(s)', len(playlists))
@@ -163,5 +161,6 @@ class SpotifySessionManager(BaseThread, PyspotifySessionManager):
 
     def logout(self):
         """Log out from spotify"""
-        logger.debug(u'Logging out from spotify')
-        self.session.logout()
+        logger.debug(u'Logging out from Spotify')
+        if self.session:
+            self.session.logout()
