@@ -10,6 +10,7 @@ implement our own MPD server which is compatible with the numerous existing
 `MPD clients <http://mpd.wikia.com/wiki/Clients>`_.
 """
 
+from collections import namedtuple
 import re
 
 #: The MPD protocol uses UTF-8 for encoding all data.
@@ -21,12 +22,16 @@ LINE_TERMINATOR = u'\n'
 #: The MPD protocol version is 0.16.0.
 VERSION = u'0.16.0'
 
+MpdCommand = namedtuple('MpdCommand', ['name', 'auth_required'])
+
+#: List of all available commands, represented as :class:`MpdCommand` objects.
 mpd_commands = set()
+
 request_handlers = {}
 
-def handle_pattern(pattern):
+def handle_request(pattern, auth_required=True):
     """
-    Decorator for connecting command handlers to command patterns.
+    Decorator for connecting command handlers to command requests.
 
     If you use named groups in the pattern, the decorated method will get the
     groups as keyword arguments. If the group is optional, remember to give the
@@ -35,7 +40,7 @@ def handle_pattern(pattern):
     For example, if the command is ``do that thing`` the ``what`` argument will
     be ``this thing``::
 
-        @handle_pattern('^do (?P<what>.+)$')
+        @handle_request('^do (?P<what>.+)$')
         def do(what):
             ...
 
@@ -45,7 +50,8 @@ def handle_pattern(pattern):
     def decorator(func):
         match = re.search('([a-z_]+)', pattern)
         if match is not None:
-            mpd_commands.add(match.group())
+            mpd_commands.add(
+                MpdCommand(name=match.group(), auth_required=auth_required))
         if pattern in request_handlers:
             raise ValueError(u'Tried to redefine handler for %s with %s' % (
                 pattern, func))
