@@ -20,7 +20,7 @@ def setup_console_logging(verbosity_level):
     if verbosity_level == 0:
         log_level = logging.WARNING
         log_format = settings.CONSOLE_LOG_FORMAT
-    elif verbosity_level == 2:
+    elif verbosity_level >= 2:
         log_level = logging.DEBUG
         log_format = settings.DEBUG_LOG_FORMAT
     else:
@@ -33,6 +33,9 @@ def setup_console_logging(verbosity_level):
     root = logging.getLogger('')
     root.addHandler(handler)
 
+    if verbosity_level < 3:
+        logging.getLogger('pykka').setLevel(logging.INFO)
+
 def setup_debug_logging_to_file():
     formatter = logging.Formatter(settings.DEBUG_LOG_FORMAT)
     handler = logging.handlers.RotatingFileHandler(
