@@ -1,8 +1,9 @@
-import unittest
-
 from mopidy.mixers.denon import DenonMixer
 from tests.mixers.base_test import BaseMixerTest
 
+from tests import unittest
+
+
 class DenonMixerDeviceMock(object):
     def __init__(self):
         self._open = True
@@ -24,6 +25,7 @@ class DenonMixerDeviceMock(object):
     def open(self):
         self._open = True
 
+
 class DenonMixerTest(BaseMixerTest, unittest.TestCase):
     ACTUAL_MAX = 99
     INITIAL = 1
