@@ -1,8 +1,9 @@
-import unittest
-
 from mopidy.mixers.dummy import DummyMixer
+
+from tests import unittest
 from tests.mixers.base_test import BaseMixerTest
 
+
 class DenonMixerTest(BaseMixerTest, unittest.TestCase):
     mixer_class = DummyMixer
 
